/*
 * Copyright (C) 2022 European Spallation Source ERIC.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package org.openepics.names.rest.beans.response;

import java.util.List;

import com.google.common.collect.Lists;

/**
 * This class is used to ensure response to request origin are handled in a uniform way.
 *
 * @author Lars Johansson
 */
public class ResponseBooleanList extends ResponseBoolean {

    private List<ResponseBoolean> list = Lists.newArrayList();

    /**
     * Constructor.
     */
    public ResponseBooleanList() {
        super();
    }

    /**
     * Constructor.
     *
     * @param value response value
     */
    public ResponseBooleanList(Boolean value) {
        super(value);
    }

    /**
     * Constructor.
     *
     * @param value response value
     * @param message response message
     */
    public ResponseBooleanList(Boolean value, String message) {
        super(value, message, "");
    }

    /**
     *Constructor.
     *
     * @param value response value
     * @param message response message
     * @param details response details
     */
    public ResponseBooleanList(Boolean value, String message, String details) {
        super(value, message, details);
    }

    /**
     *Constructor.
     *
     * @param value response value
     * @param message response message
     * @param details response details
     * @param field response field
     */
    public ResponseBooleanList(Boolean value, String message, String details, String field) {
        super(value, message, details, field);
    }

    /**
     * Constructor.
     *
     * @param list list of response boolean objects
     * @param value response value
     */
    public ResponseBooleanList(List<ResponseBoolean> list, Boolean value) {
        super(value);
        this.list = list;
    }

    /**
     * Constructor.
     *
     * @param list list of response boolean objects
     * @param value response value
     * @param message response message
     */
    public ResponseBooleanList(List<ResponseBoolean> list, Boolean value, String message) {
        super(value, message, "");
        this.list = list;
    }

    /**
     * Constructor.
     *
     * @param list list of response boolean objects
     * @param value response value
     * @param message response message
     * @param details response details
     */
    public ResponseBooleanList(List<ResponseBoolean> list, Boolean value, String message, String details) {
        super(value, message, details);
        this.list = list;
    }

    /**
     * Constructor.
     *
     * @param list list of response boolean objects
     * @param value response value
     * @param message response message
     * @param details response details
     * @param field response field
     */
    public ResponseBooleanList(List<ResponseBoolean> list, Boolean value, String message, String details, String field) {
        super(value, message, details, field);
        this.list = list;
    }

    /**
     * Return list of response boolean objects.
     *
     * @return list of response boolean objects
     */
    public List<ResponseBoolean> getList() {
        return this.list;
    }

}
